#!/usr/bin/python
# -*- coding: UTF-8 -*-

"""
    Huawei DLI Python SDK
    The class DliInfo of DLI Python SDK
"""

from dli.exception import DliException


class DliInfo(object):
    def __init__(self, **kwargs):
        self._region = kwargs.get('region')
        self._project_id = kwargs.get('project_id')
        self._auth_mode = kwargs.get('auth_mode')

        self._ak = kwargs.get('ak')
        self._sk = kwargs.get('sk')

        self._domain = kwargs.get('domain')
        self._dli = kwargs.get('endpoint')
        self._obs = kwargs.get('obs.endpoint')

        self._check_param()

        if self._domain is None:
            self._domain = 'myhuaweicloud.com'

        if self._dli is None:
            self._dli = 'dli.' + self._region + '.' + self._domain

        if self._obs is None:
            self._obs = 'obs.' + self._region + '.' + self._domain

    def _check_param(self):
        if self._region is None or self._region == '':
            raise DliException(msg='The region is missing.')

        if self._project_id is None or self._project_id == '':
            raise DliException(msg='The project_id is missing.')

        if self._auth_mode is None or self._auth_mode == '':
            raise DliException(msg='The auth_mode is missing.')

        if self._auth_mode == 'aksk':
            if self._ak is None or self._ak == '':
                raise DliException(msg='The ak is missing.')

            if self._sk is None or self._sk == '':
                raise DliException(msg='The sk is missing.')

    @property
    def region(self):
        return self._region

    @property
    def project_id(self):
        return self._project_id

    @property
    def ak(self):
        return self._ak

    @property
    def sk(self):
        return self._sk

    @property
    def domain(self):
        return self._domain

    @property
    def dli(self):
        return self._dli

    @property
    def obs(self):
        return self._obs
