#!/usr/bin/python
# -*- coding: UTF-8 -*-

from dli.exception import DliException


class ResultSetIterator(object):
    def __init__(self, result_set):
        self._result_set = result_set

    def __iter__(self):
        return self

    def __next__(self):
        return self.next()

    def next(self):
        try:
            ret = self._result_set.next()
            if ret is not True:
                raise StopIteration()

            return self._result_set.fetch()
        except IndexError:
            raise StopIteration()


class ResultSet(object):
    def __init__(self, job, rows=None, schema=None, page_size=100, queue_name=None):
        self._job = job
        self._queue_name = queue_name
        self._rows = []
        self._schema = []
        self._row_idx = 0
        self._local_idx = 0
        self._row_count = 0
        self._current_page = 1
        self._page_size = page_size
        self._current_row = None

        if rows is not None:
            self._row_count = len(rows)
            self._rows = rows
        else:
            raise DliException("Missing data")

    def __iter__(self):
        return ResultSetIterator(self)

    def next(self):
        if self._row_idx >= self._row_count:
            return False

        self._current_row = self._rows[self._row_idx]
        self._row_idx += 1
        return True

    def fetch(self):
        return self._current_row

    @property
    def row_count(self):
        return self._row_count
